import { Handlers, PageProps } from "$fresh/server.ts";
import { IngredientsList } from "@islands/IngredientsList.tsx";
import { MainLayout } from "@components/layouts/main.tsx";
import Counter from "@islands/Counter.tsx";
import { useSignal } from "@preact/signals";
import { getRecipe, Recipe } from "@lib/resource/recipes.ts";
import { RedirectSearchHandler } from "@islands/Search.tsx";
import { KMenu } from "@islands/KMenu.tsx";
import PageHero from "@components/PageHero.tsx";
import { Star } from "@components/Stars.tsx";

export const handler: Handlers<{ recipe: Recipe; session: unknown } | null> = {
  async GET(_, ctx) {
    const recipe = await getRecipe(ctx.params.name);
    return ctx.render({ recipe, session: ctx.state.session });
  },
};

export default function Greet(
  props: PageProps<{ recipe: Recipe; session: Record<string, string> }>,
) {
  const { recipe, session } = props.data;

  const portion = recipe.meta?.portion;
  const amount = useSignal(portion || 1);

  const subline = [
    recipe?.meta?.time && `Duration ${recipe.meta.time}`,
  ].filter(Boolean) as string[];

  return (
    <MainLayout
      url={props.url}
      title={`Recipes > ${recipe.name}`}
      context={recipe}
    >
      <RedirectSearchHandler />
      <KMenu type="main" context={recipe} />

      <PageHero image={recipe.meta?.image} thumbnail={recipe.meta?.thumbnail}>
        <PageHero.Header>
          <PageHero.BackLink href="/recipes" />
          {session && (
            <PageHero.EditLink
              href={`https://notes.max-richter.dev/Recipes/${recipe.id}`}
            />
          )}
        </PageHero.Header>
        <PageHero.Footer>
          <PageHero.Title>{recipe.name}</PageHero.Title>
          <PageHero.Subline
            entries={subline}
          >
            {recipe.meta?.rating && <Star rating={recipe.meta?.rating} />}
          </PageHero.Subline>
        </PageHero.Footer>
      </PageHero>
      <div class="px-8 text-white mt-10">
        <div class="flex items-center gap-8">
          <h3 class="text-3xl my-5">Ingredients</h3>
          {portion && <Counter count={amount} />}
        </div>
        <IngredientsList
          ingredients={recipe.ingredients}
          amount={amount}
          portion={portion}
        />
        <h3 class="text-3xl my-5">Preparation</h3>
        <pre
          class="whitespace-break-spaces"
          dangerouslySetInnerHTML={{ __html: recipe.preparation || "" }}
        >
          {recipe.preparation}
        </pre>
      </div>
    </MainLayout>
  );
}
